==> brapi_proxy-0.0.8.tar.gz: brapi_proxy-0.0.8/src/brapi_proxy/core/core_lists.py <==
from flask import Response
from flask_restx import Resource, fields
import json

from .. import handler
from . import ns_api_core as namespace


parser = namespace.parser()
parser.add_argument("listType", type=str, required=False,
                    choices=["germplasm", "markers", "variants", "programs", "trials", 
                             "studies", "observationUnits", "observations", "observationVariables", "samples"],
                    help="A flag to indicate the type of objects that are referenced in a List")
parser.add_argument("listName", type=str, required=False,
                    help="The human readable name of a List")
parser.add_argument("listDbId", type=str, required=False,
                    help="The unique identifier of a List")
parser.add_argument("listSource", type=str, required=False,
                    help="A short tag to indicate the source of a list")
parser.add_argument("commonCropName", type=str, required=False,
                    help="he BrAPI Common Crop Name is the simple, generalized, widely accepted name of the organism being researched. It is most often used in multi-crop systems where digital resources need to be divided at a high level. Things like 'Maize', 'Wheat', and 'Rice' are examples of common crop names.\n\nUse this parameter to only return results associated with the given crop. \n\nUse `GET /commoncropnames` to find the list of available crops on a server.")
parser.add_argument("programDbId", type=str, required=False,
                    help="Use this parameter to only return results associated with the given `Program` unique identifier. \n<br/>Use `GET /programs` to find the list of available `Programs` on a server.")
parser.add_argument("page", type=int, required=False, 
        help="Used to request a specific page of data to be returned<br>The page indexing starts at 0 (the first page is 'page'= 0). Default is `0`")
parser.add_argument("pageSize", type=int, required=False,
        help="The size of the pages to be returned. Default is `1000`")
parser.add_argument("Authorization", type=str, required=False,
        help="HTTP HEADER - Token used for Authorization<br>**Bearer {token_string}**", 
        location="headers")

newRequestItem = namespace.model("List", {})

parserPost = namespace.parser()
parserPost.add_argument("Authorization", type=str, required=False,
        help="HTTP HEADER - Token used for Authorization<br>**Bearer {token_string}**", 
        location="headers")

class CoreLists(Resource):

    @namespace.expect(parser, validate=True)
    @handler.authorization
    def get(self):
        args = parser.parse_args(strict=True)
        try:            
            #get parameters
            page = int(args["page"]) if not args["page"] is None else 0
            pageSize = int(args["pageSize"]) if not args["pageSize"] is None else 1000
            params = {"page": page, "pageSize": pageSize}
            for key,value in args.items():
                if not key in ["page","pageSize","Authorization"]:
                    if not value is None:
                        params[key] = value
            brapiResponse,brapiStatus,brapiError = handler.brapiRepaginateRequestResponse(
                self.api.brapi, "lists", params=params)
            if brapiResponse:
                return Response(json.dumps(brapiResponse), mimetype="application/json")
            else:
                response = Response(json.dumps(str(brapiError)), mimetype="application/json")
                response.status_code = brapiStatus
                return response
        except Exception as e:
            response = Response(json.dumps(str(e)), mimetype="application/json")
            response.status_code = 500
            return response

    @namespace.expect(parserPost,[newRequestItem])
    @handler.authorization
    def post(self):
        response = Response("to be implemented", mimetype="content/text")
        response.status_code = 500
        return response

    def _methods(shared,servers):
        if len(servers)==1 and ("post","lists") in shared:
            return ["get","post"]
        else:
            return ["get"]
            

parserId = namespace.parser()
parserId.add_argument("Authorization", type=str, required=False,
        help="HTTP HEADER - Token used for Authorization<br>**Bearer {token_string}**", 
        location="headers")
            
class CoreListsId(Resource):

    @namespace.expect(parserId, validate=True)
    @handler.authorization
    def get(self,listDbId):
        parser.parse_args(strict=True)
        try:
            brapiResponse,brapiStatus,brapiError = handler.brapiIdRequestResponse(
                self.api.brapi, "lists", "listDbId", listDbId)
            if brapiResponse:
                return Response(json.dumps(brapiResponse), mimetype="application/json")
            else:
                response = Response(json.dumps(str(brapiError)), mimetype="application/json")
                response.status_code = brapiStatus
                return response
        except Exception as e:
            response = Response(json.dumps(str(e)), mimetype="application/json")
            response.status_code = 500
            return response

==> brapi_proxy-0.0.15.tar.gz: brapi_proxy-0.0.15/src/brapi_proxy/core/core_lists.py <==
from flask import Response
from flask_restx import Resource, fields
import json

from .. import handler
from . import ns_api_core as namespace


parser = namespace.parser()
parser.add_argument("listType", type=str, required=False,
                    choices=["germplasm", "markers", "variants", "programs", "trials", 
                             "studies", "observationUnits", "observations", "observationVariables", "samples"],
                    help="A flag to indicate the type of objects that are referenced in a List")
parser.add_argument("listName", type=str, required=False,
                    help="The human readable name of a List")
parser.add_argument("listDbId", type=str, required=False,
                    help="The unique identifier of a List")
parser.add_argument("listSource", type=str, required=False,
                    help="A short tag to indicate the source of a list")
parser.add_argument("commonCropName", type=str, required=False,
                    help="he BrAPI Common Crop Name is the simple, generalized, widely accepted name of the organism being researched. It is most often used in multi-crop systems where digital resources need to be divided at a high level. Things like 'Maize', 'Wheat', and 'Rice' are examples of common crop names.\n\nUse this parameter to only return results associated with the given crop. \n\nUse `GET /commoncropnames` to find the list of available crops on a server.")
parser.add_argument("programDbId", type=str, required=False,
                    help="Use this parameter to only return results associated with the given `Program` unique identifier. \n<br/>Use `GET /programs` to find the list of available `Programs` on a server.")
parser.add_argument("page", type=int, required=False, 
        help="Used to request a specific page of data to be returned<br>The page indexing starts at 0 (the first page is 'page'= 0). Default is `0`")
parser.add_argument("pageSize", type=int, required=False,
        help="The size of the pages to be returned. Default is `1000`")
parser.add_argument("Authorization", type=str, required=False,
        help="HTTP HEADER - Token used for Authorization<br>**Bearer {token_string}**", 
        location="headers")

class CoreLists(Resource):

    @namespace.expect(parser, validate=True)
    @handler.authorization
    def get(self):
        strict = self.api.config.getboolean("brapi","strict") if self.api.config.has_option("brapi","strict") else False
        args = parser.parse_args(strict=strict)
        try:            
            #get parameters
            page = int(args["page"]) if not args["page"] is None else 0
            pageSize = int(args["pageSize"]) if not args["pageSize"] is None else 1000
            params = {"page": page, "pageSize": pageSize}
            for key,value in args.items():
                if not key in ["page","pageSize","Authorization"]:
                    if not value is None:
                        params[key] = value
            brapiResponse,brapiStatus,brapiError = handler.brapiRepaginateRequestResponse(
                self.api.brapi, "lists", params=params)
            if brapiResponse:
                return Response(json.dumps(brapiResponse), mimetype="application/json")
            else:
                response = Response(json.dumps(str(brapiError)), mimetype="application/json")
                response.status_code = brapiStatus
                return response
        except Exception as e:
            response = Response(json.dumps(str(e)), mimetype="application/json")
            response.status_code = 500
            return response            

parserId = namespace.parser()
parserId.add_argument("Authorization", type=str, required=False,
        help="HTTP HEADER - Token used for Authorization<br>**Bearer {token_string}**", 
        location="headers")
            
class CoreListsId(Resource):

    @namespace.expect(parserId, validate=True)
    @handler.authorization
    def get(self,listDbId):
        strict = self.api.config.getboolean("brapi","strict") if self.api.config.has_option("brapi","strict") else False
        args = parser.parse_args(strict=strict)
        try:
            brapiResponse,brapiStatus,brapiError = handler.brapiIdRequestResponse(
                self.api.brapi, "lists", "listDbId", listDbId)
            if brapiResponse:
                return Response(json.dumps(brapiResponse), mimetype="application/json")
            else:
                response = Response(json.dumps(str(brapiError)), mimetype="application/json")
                response.status_code = brapiStatus
                return response
        except Exception as e:
            response = Response(json.dumps(str(e)), mimetype="application/json")
            response.status_code = 500
            return response
